pub struct Measurement {
pub tracker: String,
pub epoch: Epoch,
pub data: IndexMap<MeasurementType, f64>,
pub rejected: bool,
}Expand description
A type-agnostic simultaneous measurement storage structure. Allows storing any number of simultaneous measurement of a given taker.
Note that two measurements are considered equal if the tracker and epoch match exactly, and if both have the same measurement types, and those measurements are equal to within 1e-10 (this allows for some leeway in TDM producers).
Fields
tracker: StringTracker alias which made this measurement
epoch: EpochEpoch of the measurement
data: IndexMap<MeasurementType, f64>All measurements made simultaneously
rejected: boolWhether this measurement has been manually rejected
Implementations
Sourceimpl Measurement
impl Measurement
Sourcepub fn correct(&mut self, msr_type: MeasurementType, correction: f64)
pub fn correct(&mut self, msr_type: MeasurementType, correction: f64)
Correct the provided measurement type with the provided correction, if that measurement type is available
pub fn push(&mut self, msr_type: MeasurementType, msr_value: f64)
Sourceimpl Measurement
impl Measurement
pub fn new(tracker: String, epoch: Epoch) -> Self
pub fn with(self, msr_type: MeasurementType, msr_value: f64) -> Self
Sourcepub fn observation<S: DimName>(
&self,
types: &IndexSet<MeasurementType>,
) -> OVector<f64, S>where
DefaultAllocator: Allocator<S>,
pub fn observation<S: DimName>(
&self,
types: &IndexSet<MeasurementType>,
) -> OVector<f64, S>where
DefaultAllocator: Allocator<S>,
Builds an observation vector for this measurement provided a set of measurement types. If the requested measurement type is not available, then that specific row is set to zero. The caller must set the appropriate sensitivity matrix rows to zero.
Sourcepub fn availability(&self, types: &IndexSet<MeasurementType>) -> Vec<bool>
pub fn availability(&self, types: &IndexSet<MeasurementType>) -> Vec<bool>
Returns a vector specifying which measurement types are available.